pub struct PartneredLtlDataOutput {
Show 15 fields pub contact: Box<Contact>, pub box_count: i64, pub seller_freight_class: Option<SellerFreightClass>, pub freight_ready_date: String, pub pallet_list: Vec<Pallet>, pub total_weight: Box<Weight>, pub seller_declared_value: Option<Box<Amount>>, pub amazon_calculated_value: Option<Box<Amount>>, pub preview_pickup_date: String, pub preview_delivery_date: String, pub preview_freight_class: SellerFreightClass, pub amazon_reference_id: String, pub is_bill_of_lading_available: bool, pub partnered_estimate: Option<Box<PartneredEstimate>>, pub carrier_name: String,
}
PartneredLtlDataOutput : Information returned by Amazon about a Less Than Truckload/Full Truckload (LTL/FTL) shipment by an Amazon-partnered carrier.

Fields

contact: Box<Contact>box_count: i64seller_freight_class: Option<SellerFreightClass>freight_ready_date: Stringpallet_list: Vec<Pallet>

A list of pallet information.

total_weight: Box<Weight>seller_declared_value: Option<Box<Amount>>amazon_calculated_value: Option<Box<Amount>>preview_pickup_date: Stringpreview_delivery_date: Stringpreview_freight_class: SellerFreightClassamazon_reference_id: String

A unique identifier created by Amazon that identifies this Amazon-partnered, Less Than Truckload/Full Truckload (LTL/FTL) shipment.

is_bill_of_lading_available: bool

Indicates whether the bill of lading for the shipment is available.

partnered_estimate: Option<Box<PartneredEstimate>>carrier_name: String

The carrier for the inbound shipment.

Implementations

Information returned by Amazon about a Less Than Truckload/Full Truckload (LTL/FTL) shipment by an Amazon-partnered carrier.